pub struct ExportedStoreCipher {
pub kdf_info: KdfInfo,
pub ciphertext_info: CiphertextInfo,
}Fields
kdf_info: KdfInfoInfo about the key derivation method that was used to expand the passphrase into an encryption key.
ciphertext_info: CiphertextInfoThe ciphertext of known plaintext and additional data that is needed to verify correct key derivation and cipher choice.